package com.abi.qms.platform.service.impl;

import com.abi.qms.platform.dao.entity.QrVariable;
import com.abi.qms.platform.dao.mapper.QrVariableMapper;
import com.abi.qms.platform.dto.req.ListQrVariableReq;
import com.abi.qms.platform.dto.req.PreviewQrVariableReq;
import com.abi.qms.platform.dto.res.ListQrVariableRes;
import com.abi.qms.platform.dto.res.PreviewQrVariableRes;
import com.abi.qms.platform.infrastructure.util.AssertUtil;
import com.abi.qms.platform.infrastructure.util.BuildCodeUtil;
import com.abi.qms.platform.infrastructure.util.PageUtil;
import com.abi.qms.platform.service.QrVariableService;
import com.abi.task.common.utils.PojoConverterUtils;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 码格式变量 Service业务层处理
 *
 * @author WeiganCai
 * @date 2021-04-19
 */
@Service
public class QrVariableServiceImpl implements QrVariableService {

	@Autowired
	private QrVariableMapper qrVariableMapper;

	/**
	 *  码格式变量查询分页
	 */
	@Override
	public ListQrVariableRes listQrVariable(ListQrVariableReq req) {
		// 拼接条件
		QueryWrapper<QrVariable> qrVariableQw = new QueryWrapper<>();
		qrVariableQw.eq("is_delete", 0);
		qrVariableQw.eq(req.getValid() != null, "valid", req.getValid());
		qrVariableQw.eq(req.getDataType() != null, "data_type", req.getDataType());
		qrVariableQw.eq(req.getParamType() != null, "param_type", req.getParamType());
		qrVariableQw.orderByAsc("sort_number");

		// 分页查询
		IPage<QrVariable> iPage = qrVariableMapper.selectPage(PageUtil.createPage(req), qrVariableQw);
		List<QrVariable> qrVariableList = iPage.getRecords();

		// 封装出参、放入分页信息
		ListQrVariableRes res = new ListQrVariableRes();
		PageUtil.copyPageInfo(res, iPage);
		List<ListQrVariableRes.QrVariableBean> qrVariableBeanList = PojoConverterUtils.copyList(qrVariableList, ListQrVariableRes.QrVariableBean.class);
		res.setQrVariableBeanList(qrVariableBeanList);

		return res;
	}

	/**
	 * 码格式变量生成码预览
	 */
	@Override
	public PreviewQrVariableRes previewQrVariable(PreviewQrVariableReq req) {
		// 查询码格式变量
		QrVariable qrVariable = qrVariableMapper.selectById(req.getId());
		AssertUtil.isNull(qrVariable,"码格式变量不存在");

		// 生成单个码
		String code = BuildCodeUtil.buildSingleCode(qrVariable.getBuildCodeClass(), null);
		PreviewQrVariableRes res = new PreviewQrVariableRes();
		res.setCode(code);

		return res;
	}
}
